app/soc/models/request.py
changeset 1085 0afbdd0905ef
parent 970 8b5611d5b053
child 1307 091a21cf3627
--- a/app/soc/models/request.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/models/request.py	Fri Jan 30 17:38:28 2009 +0000
@@ -42,7 +42,7 @@
   role_verbose.help_text = ugettext(
       'This should be the verbose name of the role that is in this request')
 
   # property that determines the state of the request
   # new : new Request
   # group_accepted : The group has accepted this request
   # completed : This request has been handled either following a creation of
@@ -50,8 +50,8 @@
   # rejected : This request has been rejected by either the user or the group
   # ignored : The request has been ignored by the group and will not give
   #           the user access to create the role
-  state = db.StringProperty(required=True, default='new',
+  status = db.StringProperty(required=True, default='new',
       choices=['new', 'group_accepted', 'completed', 'rejected','ignored'])
-  state.help_text = ugettext('Shows the state of the request')
+  status.help_text = ugettext('Shows the status of the request')
@@ -42,7 +42,7 @@
       'This should be the verbose name of the role that is in this request')
 
-  # property that determines the state of the request
+  # property that determines the status of the request
   # new : new Request
   # group_accepted : The group has accepted this request